#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
#
# Cisco WLC metrics plugin
#
# Author: Th.L.
# Date  : 2018-01-06
#
#
# missing a way to include hostname and service description
#

# key a       green      11/a       21/a       31/a       41/a       12/a       22/a       32/a       42/a
colors_a = ['#80F000', '#a500ff', '#ffc600', '#00ffb2', '#0075ff', '#cc00ff', '#ffd600', '#00ffff', '#0047ff',
            # 13/a       23/a       33/a       43/a       14/a       24/a       34/a       44/a       15/a
            '#f900ff', '#ffed00', '#00e8ff', '#000aff', '#ff4c00', '#e2ff00', '#00d1ff', '#4200ff', '#ff7a00',
            # 25/a       35/a       45/a       16/a       26/a       36/a       46/a       51/a       52/a
            '#bcff00', '#00b2ff', '#6000ff', '#ffa000', '#7fff00', '#0093ff', '#7f00ff', '#7f7f7f', '#7f4a26',
            # 53/a
            '#8c531c']
# key b       green      21/b       31/b       41/b       12/b       22/b       32/b       42/b       13/b
colors_b = ['#80F000', '#c966ff', '#cc9f00', '#00cc8e', '#66acff', '#e066ff', '#ccab00', '#00cccc', '#6690ff',
            # 23/b       33/b       43/b       14/b       24/b       34/b       44/b       15/b       25/b
            '#fb66ff', '#ccbd00', '#00b9cc', '#666cff', '#ff9366', '#b5cc00', '#00a7cc', '#8d66ff', '#ffaf66',
            # 35/b       45/b       16/b       26/b       36/b       46/b       51/b       52/b       53/b
            '#96cc00', '#008ecc', '#a066ff', '#ffc666', '#66cc00', '#0076cc', '#b266ff', '#7f7f7f', '#7f5f49',
            '#8c6a48']


#####################################################################################################################
#
# define units for perfdata
#
#####################################################################################################################


#####################################################################################################################
#
# define metrics for perfdata
#
#####################################################################################################################

metric_info['cisco_wlc_uptime_seconds'] = {
    'title': _('AP uptime'),
    'help': _(''),
    'unit': 's',
    'color': colors_a[0],
}

metric_info['cisco_wlc_active_client_count'] = {
    'title': _('Active clients'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[1],
}

metric_info['cisco_wlc_reassoiation_success_count'] = {
    'title': _('Reassoiation success'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[2],
}

metric_info['cisco_wlc_reassoiation_failure_count'] = {
    'title': _('Reassoiation failure'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[3],
}

metric_info['cisco_wlc_reassoiation_failure_count_by_rate'] = {
    'title': _('Reassoiation failure rate'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[4],
}

metric_info['cisco_wlc_echo_request_count'] = {
    'title': _('Echo request'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[5],
}

metric_info['cisco_wlc_echo_response_loss_count'] = {
    'title': _('Echo response loss'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[6],
}

metric_info['cisco_wlc_association_fail_count_for_rssi_low'] = {
    'title': _('Association fail rssi low'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[7],
}

metric_info['cisco_wlc_association_fail_times'] = {
    'title': _('Association fail times'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[8],
}

metric_info['cisco_wlc_association_count'] = {
    'title': _('Associations'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[9],
}

metric_info['cisco_wlc_associated_clients'] = {
    'title': _('Associated clients'),
    'help': _(''),
    'unit': 'count',
    'color': colors_a[10],
}

######################################################################################################################
#
# map perfdata to metric, not really necessary but makes sure to use the right metrics
#
######################################################################################################################

check_metrics['check_mk-cisco_wlc'] = {
    'uptime_seconds': {'name': 'cisco_wlc_uptime_seconds', },
    'reassoiation_success_count': {'name': 'cisco_wlc_reassoiation_success_count', },
    'reassoiation_failure_count': {'name': 'cisco_wlc_reassoiation_failure_count', },
    'active_client_count': {'name': 'cisco_wlc_active_client_count', },
    'associated_clients': {'name': 'cisco_wlc_associated_clients'},
    'association_count': {'name': 'cisco_wlc_association_count'},
    'association_fail_count_for_rssi_low': {'name': 'cisco_wlc_association_fail_count_for_rssi_low', },
    'association_fail_times': {'name': 'cisco_wlc_association_fail_times', },
    'echo_request_count': {'name': 'cisco_wlc_echo_request_count', },
    'echo_response_loss_count': {'name': 'cisco_wlc_echo_response_loss_count', },
}

######################################################################################################################
#
# how to graph perdata
#
######################################################################################################################

graph_info.append({
    'title': _('AP Uptime'),
    'metrics': [
        ('cisco_wlc_uptime_seconds', 'area'),
    ],
})

graph_info.append({
    'title': _('Active clients'),
    'metrics': [
        ('cisco_wlc_active_client_count', 'line'),
        ('cisco_wlc_associated_clients', 'line')
    ],
})

graph_info.append({
    'title': _('Counters'),
    'metrics': [
        ('cisco_wlc_reassoiation_success_count', 'line'),
        ('cisco_wlc_reassoiation_failure_count', 'line'),
        ('cisco_wlc_association_fail_times', 'line'),
        ('cisco_wlc_association_fail_count_for_rssi_low', 'line'),
        ('cisco_wlc_association_count', 'line'),

    ],
})

graph_info.append({
    'title': _('Echos'),
    'metrics': [
        ('cisco_wlc_echo_request_count', 'line'),
        ('cisco_wlc_echo_response_loss_count', '-line'),
    ],
})

######################################################################################################################
#
# define perf-o-meter
#
######################################################################################################################

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'cisco_wlc_uptime_seconds',
        'half_value': 2592000.0,
        'exponent': 2,
    },
    {
        'type': 'linear',
        'segments': ['cisco_wlc_active_client_count'],
        'total': 200,
    }
]))
